@@ -14,6 +14,7 @@ type treeSimple struct {
 	mkdirer      mkdirerSimple
 	verifier     verifierSimple
 	growSpreader growSpreaderSimple
+	walker       walkerSimple
 }
 
 var _ tree = (*treeSimple)(nil)
@@ -45,6 +46,10 @@ func newTreeSimple(cfg *config) tree {
 		return newGrowSpreaderSimple(lastNodeFormat, intermedialNodeFormat)
 	}
 
+	walkerFactory := func() walkerSimple {
+		return newWalkerSimple()
+	}
+
 	return &treeSimple{
 		grower: growerFactory(
 			cfg.lastNodeFormat,
@@ -69,6 +74,7 @@ func newTreeSimple(cfg *config) tree {
 			cfg.lastNodeFormat,
 			cfg.intermedialNodeFormat,
 		),
+		walker: walkerFactory(),
 	}
 }
 
@@ -144,6 +150,25 @@ func (t *treeSimple) verifyProgrammably(root *Node, cfg *config) error {
 	return t.verifier.verify([]*Node{root})
 }
 
+func (t *treeSimple) walk(r io.Reader, cb func(*WalkerNode) error, cfg *config) error {
+	roots, err := newRootGeneratorSimple(r).generate()
+	if err != nil {
+		return err
+	}
+
+	if err := t.grower.grow(roots); err != nil {
+		return err
+	}
+	return t.walker.walk(roots, cb)
+}
+
+func (t *treeSimple) walkProgrammably(root *Node, cb func(*WalkerNode) error, cfg *config) error {
+	if err := t.grower.grow([]*Node{root}); err != nil {
+		return err
+	}
+	return t.walker.walk([]*Node{root}, cb)
+}
+
 // 関心事は各ノードの枝の形成
 type growerSimple interface {
 	grow([]*Node) error
@@ -173,3 +198,7 @@ type verifierSimple interface {
 type growSpreaderSimple interface {
 	growAndSpread(io.Writer, []*Node) error
 }
+
+type walkerSimple interface {
+	walk([]*Node, func(*WalkerNode) error) error
+}
