@@ -9,20 +9,23 @@ import (
 // Output outputs a tree to w with r as Markdown format input.
 func Output(w io.Writer, r io.Reader, options ...Option) error {
 	cfg := newConfig(options)
-	tree := initializeTree(cfg)
-	return tree.output(w, r, cfg)
+	return initializeTree(cfg).output(w, r, cfg)
 }
 
 // Mkdir makes directories.
 func Mkdir(r io.Reader, options ...Option) error {
 	cfg := newConfig(options)
-	tree := initializeTree(cfg)
-	return tree.mkdir(r, cfg)
+	return initializeTree(cfg).mkdir(r, cfg)
 }
 
 // Verify verifies directories.
 func Verify(r io.Reader, options ...Option) error {
 	cfg := newConfig(options)
-	tree := initializeTree(cfg)
-	return tree.verify(r, cfg)
+	return initializeTree(cfg).verify(r, cfg)
+}
+
+// Walk executes user-defined function while traversing tree structure recursively.
+func Walk(r io.Reader, cb func(*WalkerNode) error, options ...Option) error {
+	cfg := newConfig(options)
+	return initializeTree(cfg).walk(r, cb, cfg)
 }
